snoop-cli-0.1.0 is not a library.
snoop
A tool suite for inspecting Solana programs
Installation
Cargo
Usage
Disassemble
Disassemble a compiled program binary, and print to stdout, or optionally write to a .s file
Cfg
Inspect the program's config
Graph
Generate a graphviz of a given program binary
Functions
View all functions defined in the binary
Credits
This project draws inspiration from the work of Dean Little and makes heavy use of theSolana Labs rBPF Toolkit.
Disclaimer
This project is a work in progress. Proceed with caution.